pm4py.algo.analysis.extended\_marking\_equation.variants package
================================================================

Submodules
----------

pm4py.algo.analysis.extended\_marking\_equation.variants.classic module
-----------------------------------------------------------------------

.. automodule:: pm4py.algo.analysis.extended_marking_equation.variants.classic
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.analysis.extended_marking_equation.variants
   :members:
   :undoc-members:
   :show-inheritance:
